==> okta-sdk-api-19.0.1-sources.jar: com/okta/sdk/resource/model/UserFactorTokenHOTP.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonIgnoreProperties;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonSubTypes;
import com.fasterxml.jackson.annotation.JsonTypeInfo;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.UserFactor;
import com.okta.sdk.resource.model.UserFactorLinks;
import com.okta.sdk.resource.model.UserFactorProvider;
import com.okta.sdk.resource.model.UserFactorStatus;
import com.okta.sdk.resource.model.UserFactorTokenHOTPProfile;
import com.okta.sdk.resource.model.UserFactorType;
import java.time.OffsetDateTime;
import java.util.HashMap;
import java.util.Map;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * UserFactorTokenHOTP
 */
@JsonPropertyOrder({ UserFactorTokenHOTP.JSON_PROPERTY_FACTOR_PROFILE_ID, UserFactorTokenHOTP.JSON_PROPERTY_PROFILE })
@javax.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2024-10-04T18:50:18.667445-05:00[America/Chicago]", comments = "Generator version: 7.8.0")
@JsonTypeInfo(use = JsonTypeInfo.Id.NAME, include = JsonTypeInfo.As.EXISTING_PROPERTY, property = "factorType", visible = true, defaultImpl = UserFactorTokenHOTP.class)

public class UserFactorTokenHOTP extends UserFactor implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_FACTOR_PROFILE_ID = "factorProfileId";
    private String factorProfileId;

    public static final String JSON_PROPERTY_PROFILE = "profile";
    private UserFactorTokenHOTPProfile profile;

    public UserFactorTokenHOTP() {
    }

    /*
     * @JsonCreator public UserFactorTokenHOTP(
     *
     * @JsonProperty(JSON_PROPERTY_CREATED) OffsetDateTime created,
     *
     * @JsonProperty(JSON_PROPERTY_ID) String id,
     *
     * @JsonProperty(JSON_PROPERTY_LAST_UPDATED) OffsetDateTime lastUpdated,
     *
     * @JsonProperty(JSON_PROPERTY_VENDOR_NAME) String vendorName,
     *
     * @JsonProperty(JSON_PROPERTY_EMBEDDED) Map<String, Object> embedded ) { this(); this.created = created; this.id =
     * id; this.lastUpdated = lastUpdated; this.vendorName = vendorName; this.embedded = embedded; }
     */

    public UserFactorTokenHOTP factorProfileId(String factorProfileId) {

        this.factorProfileId = factorProfileId;
        return this;
    }

    /**
     * ID of an existing Custom TOTP Factor profile. To create this, see [Custom TOTP
     * Factor](https://help.okta.com/okta_help.htm?id&#x3D;ext-mfa-totp).
     *
     * @return factorProfileId
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "ID of an existing Custom TOTP Factor profile. To create this, see [Custom TOTP Factor](https://help.okta.com/okta_help.htm?id=ext-mfa-totp).")
    @JsonProperty(JSON_PROPERTY_FACTOR_PROFILE_ID)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getFactorProfileId() {
        return factorProfileId;
    }

    @JsonProperty(JSON_PROPERTY_FACTOR_PROFILE_ID)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setFactorProfileId(String factorProfileId) {
        this.factorProfileId = factorProfileId;
    }

    public UserFactorTokenHOTP profile(UserFactorTokenHOTPProfile profile) {

        this.profile = profile;
        return this;
    }

    /**
     * Get profile
     *
     * @return profile
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_PROFILE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public UserFactorTokenHOTPProfile getProfile() {
        return profile;
    }

    @JsonProperty(JSON_PROPERTY_PROFILE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setProfile(UserFactorTokenHOTPProfile profile) {
        this.profile = profile;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        UserFactorTokenHOTP userFactorTokenHOTP = (UserFactorTokenHOTP) o;
        return Objects.equals(this.factorProfileId, userFactorTokenHOTP.factorProfileId)
                && Objects.equals(this.profile, userFactorTokenHOTP.profile);
        // && super.equals(o);
    }

    @Override
    public int hashCode() {
        return Objects.hash(factorProfileId, profile, super.hashCode());
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class UserFactorTokenHOTP {\n");
        sb.append("    ").append(toIndentedString(super.toString())).append("\n");
        sb.append("    factorProfileId: ").append(toIndentedString(factorProfileId)).append("\n");
        sb.append("    profile: ").append(toIndentedString(profile)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-24.0.0-sources.jar: com/okta/sdk/resource/model/UserFactorTokenHOTP.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonIgnoreProperties;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonSubTypes;
import com.fasterxml.jackson.annotation.JsonTypeInfo;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.UserFactor;
import com.okta.sdk.resource.model.UserFactorLinks;
import com.okta.sdk.resource.model.UserFactorProvider;
import com.okta.sdk.resource.model.UserFactorStatus;
import com.okta.sdk.resource.model.UserFactorTokenHOTPProfile;
import com.okta.sdk.resource.model.UserFactorType;
import java.time.OffsetDateTime;
import java.util.HashMap;
import java.util.Map;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * UserFactorTokenHOTP
 */
@JsonPropertyOrder({ UserFactorTokenHOTP.JSON_PROPERTY_FACTOR_PROFILE_ID, UserFactorTokenHOTP.JSON_PROPERTY_PROFILE })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-07-28T10:14:57.946459+05:30[Asia/Kolkata]", comments = "Generator version: 7.11.0")
@JsonTypeInfo(use = JsonTypeInfo.Id.NAME, include = JsonTypeInfo.As.EXISTING_PROPERTY, property = "factorType", visible = true, defaultImpl = UserFactorTokenHOTP.class)

public class UserFactorTokenHOTP extends UserFactor implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_FACTOR_PROFILE_ID = "factorProfileId";
    private String factorProfileId;

    public static final String JSON_PROPERTY_PROFILE = "profile";
    private UserFactorTokenHOTPProfile profile;

    public UserFactorTokenHOTP() {
    }

    /*
     * @JsonCreator public UserFactorTokenHOTP(
     *
     * @JsonProperty(JSON_PROPERTY_CREATED) OffsetDateTime created,
     *
     * @JsonProperty(JSON_PROPERTY_ID) String id,
     *
     * @JsonProperty(JSON_PROPERTY_LAST_UPDATED) OffsetDateTime lastUpdated,
     *
     * @JsonProperty(JSON_PROPERTY_VENDOR_NAME) String vendorName,
     *
     * @JsonProperty(JSON_PROPERTY_EMBEDDED) Map<String, Object> embedded ) { this(); this.created = created; this.id =
     * id; this.lastUpdated = lastUpdated; this.vendorName = vendorName; this.embedded = embedded; }
     */

    public UserFactorTokenHOTP factorProfileId(String factorProfileId) {

        this.factorProfileId = factorProfileId;
        return this;
    }

    /**
     * ID of an existing Custom TOTP Factor profile. To create this, see [Custom TOTP
     * Factor](https://help.okta.com/okta_help.htm?id&#x3D;ext-mfa-totp).
     *
     * @return factorProfileId
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "ID of an existing Custom TOTP Factor profile. To create this, see [Custom TOTP Factor](https://help.okta.com/okta_help.htm?id=ext-mfa-totp).")
    @JsonProperty(JSON_PROPERTY_FACTOR_PROFILE_ID)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getFactorProfileId() {
        return factorProfileId;
    }

    @JsonProperty(JSON_PROPERTY_FACTOR_PROFILE_ID)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setFactorProfileId(String factorProfileId) {
        this.factorProfileId = factorProfileId;
    }

    public UserFactorTokenHOTP profile(UserFactorTokenHOTPProfile profile) {

        this.profile = profile;
        return this;
    }

    /**
     * Get profile
     *
     * @return profile
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_PROFILE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public UserFactorTokenHOTPProfile getProfile() {
        return profile;
    }

    @JsonProperty(JSON_PROPERTY_PROFILE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setProfile(UserFactorTokenHOTPProfile profile) {
        this.profile = profile;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        UserFactorTokenHOTP userFactorTokenHOTP = (UserFactorTokenHOTP) o;
        return Objects.equals(this.factorProfileId, userFactorTokenHOTP.factorProfileId)
                && Objects.equals(this.profile, userFactorTokenHOTP.profile);
        // && super.equals(o);
    }

    @Override
    public int hashCode() {
        return Objects.hash(factorProfileId, profile, super.hashCode());
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class UserFactorTokenHOTP {\n");
        sb.append("    ").append(toIndentedString(super.toString())).append("\n");
        sb.append("    factorProfileId: ").append(toIndentedString(factorProfileId)).append("\n");
        sb.append("    profile: ").append(toIndentedString(profile)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
